# SBMLDiagrams
[![Coverage](https://codecov.io/gh/sunnyXu/SBMLDiagrams/branch/main/graph/badge.svg)](https://codecov.io/gh/sunnyXu/SBMLDiagrams)

[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT) [![PyPI version](https://badge.fury.io/py/SBMLDiagrams.svg)](https://badge.fury.io/py/SBMLDiagrams) [![PyPI download month](https://img.shields.io/pypi/dm/ansicolortags.svg)](https://pypi.python.org/pypi/SBMLDiagrams/) ![Funding](https://img.shields.io/badge/Funding-NIH%20(EB028887)-blue)

## Introduction

SBMLDiagrams is a Python package to visualize networks embedded in SBML Level 3 models. If the SBML layout and render extension are used, the package will use this data to display the network. SBMLDiagrams can export PNG, JPG, PDF files. SBMLDiagrams can be used to add SBML layout and render to an existing valid SBML model which can subsequently be exported.

We also have an interface of SBMLDiagrams to NetworkX to exploit the variety of layout algorithms. If you are using any of the code, please cite the article (https://doi.org/10.1093/bioinformatics/btac730) and the PYPI web page (https://pypi.org/project/SBMLDiagrams/). 

## Installation

``pip install SBMLDiagrams``

## A Figure Example

Here is a figure example visualized by SBMLDiagrams below. The Bezier reactions are organized by SBcoyote (https://arxiv.org/abs/2302.09151).

<img src="https://raw.githubusercontent.com/SunnyXu/SBMLDiagrams/main/docs/Figures/Introduction/Jana_WolfGlycolysis.png" width="350" height="450">


Its animation is also available at https://youtu.be/zF3_fkDp2Xk. 
Please see more figure examples in the documentation.

## Documentation
Please see the documentation at https://sys-bio.github.io/SBMLDiagrams/ for details.


